@@ -14,8 +14,8 @@
 
 from tempest import clients
 
+from monasca_tempest_tests.services import elasticsearch_client
 from monasca_tempest_tests.services import log_api_v3_client
-from monasca_tempest_tests.services import log_search_client
 
 
 class Manager(clients.Manager):
@@ -28,7 +28,7 @@ class Manager(clients.Manager):
             None
         )
 
-        self.log_search_client = log_search_client.LogsSearchClient(
+        self.log_search_client = elasticsearch_client.ElasticsearchClient(
             self.auth_provider,
             'logs-search',
             None
